@@ -1,5 +1,5 @@
 import pandas as pd
-import pytds
+import pymssql
 from mindsdb_native.libs.data_types.data_source import SQLDataSource
 
 
@@ -7,14 +7,14 @@ class MSSQLDS(SQLDataSource):
     def __init__(self, query, database='master', host='localhost',
                port=1433, user='sa', password=''):
         super().__init__(query=query)
-        self.database_ = database
+        self.database = database
         self.host = host
         self.port = int(port)
         self.user = user
         self.password = password
 
     def query(self, q):
-        with pytds.connect(dsn=self.host, user=self.user, password=self.password, database=self.database) as con:
+        with pymssql.connect(server=self.host, host=self.host, user=self.user, password=self.password, database=self.database, port=self.port) as con:
             df = pd.read_sql(q, con=con)
         return df, self._make_colmap(df)
 
