@@ -12,6 +12,7 @@ import torch
 from sklearn import preprocessing
 from sklearn.linear_model import LinearRegression
 from sklearn.metrics import r2_score, f1_score, accuracy_score
+from sklearn.datasets import load_iris
 
 from mindsdb_native import F
 from mindsdb_native.libs.data_sources.file_ds import FileDS
@@ -32,40 +33,6 @@ class TestPredictor(unittest.TestCase):
     def setUp(self):
         self.tmp_dir = tempfile.mkdtemp()
 
-    def test_sample_for_training(self):
-        predictor = Predictor(name='test_sample_for_training')
-        assert predictor.report_uuid == 'no_report'
-
-        n_points = 100
-        input_dataframe = pd.DataFrame({
-            'numeric_int': [x % 10 for x in list(range(n_points))],
-            'categorical_binary': [0, 1] * (n_points // 2),
-        })
-        input_dataframe['y'] = input_dataframe.numeric_int + input_dataframe.numeric_int * input_dataframe.categorical_binary
-
-        sample_settings = {
-            'sample_for_training': True,
-            'sample_for_analysis': True,
-            'sample_function': mock.MagicMock(wraps=sample_data),
-        }
-        setattr(sample_settings['sample_function'], '__name__', 'sample_data')
-
-        predictor.learn(
-            from_data=input_dataframe,
-            to_predict='y',
-            backend='lightwood',
-            sample_settings=sample_settings,
-            stop_training_in_x_seconds=1,
-            use_gpu=False
-        )
-
-        assert sample_settings['sample_function'].called
-
-        # 1 call when sampling for analysis
-        # 1 call when sampling training data for lightwood
-        # 1 call when sampling testing data for lightwood
-        assert sample_settings['sample_function'].call_count == 3
-
     def test_explain_prediction(self):
         mdb = Predictor(name='test_explain_prediction')
 
@@ -179,8 +146,7 @@ class TestPredictor(unittest.TestCase):
         )
 
         results = mdb.predict(when_data=test_file_name)
-        models = F.get_models()
-        model_data = F.get_model_data(models[0]['name'])
+        model_data = F.get_model_data('test_multilabel_prediction')
         assert model_data
 
         for i in range(len(results)):
@@ -484,3 +450,24 @@ class TestPredictor(unittest.TestCase):
         )
 
         mdb.predict(when_data={'categorical_x': 0})
+
+    def test_output_class_distribution(self):
+        mdb = Predictor(name='test_output_class_distribution')
+        data = load_iris(as_frame=True)
+        df = data.data
+        df['target'] = data.target
+
+        mdb.learn(
+            from_data=df,
+            to_predict='target',
+            stop_training_in_x_seconds=1,
+            use_gpu=False,
+            advanced_args={'debug': True, 'output_class_distribution': True}
+        )
+
+        results = mdb.predict(when_data=data.data.iloc[[0]])
+        assert 'target_class_distribution' in results._data
+        probs = results._data['target_class_distribution']
+        assert np.isclose(np.sum(probs), 1)
+        for dist in probs:
+            assert len(dist) == data.target_names.size
